@@ -50,7 +50,11 @@ inline_elements = [
     (text_uri, 'ruby-base'),
     (text_uri, 's'),
     (text_uri, 'span'),
-    (text_uri, 'tab')]
+    (text_uri, 'tab'),
+
+    (text_uri, 'bibliography-mark'),
+    (text_uri, 'user-field-get'),
+    (text_uri, 'reference-ref')]
 
 skip_content_elements = [
 
@@ -139,7 +143,7 @@ skip_content_elements = [
     (text_uri, 'print-date'),
     (text_uri, 'print-time'),
     (text_uri, 'printed-by'),
-    (text_uri, 'reference-ref'),
+    #(text_uri, 'reference-ref'),
     #(text_uri, 'ruby-text'),
     (text_uri, 'script'),
     (text_uri, 'sender-city'),
@@ -168,7 +172,7 @@ skip_content_elements = [
     (text_uri, 'time'),
     #(text_uri, 'title'),
     (text_uri, 'user-defined'),
-    (text_uri, 'user-field-get'),
+    #(text_uri, 'user-field-get'),
     (text_uri, 'user-field-input'),
     (text_uri, 'variable-get'),
     (text_uri, 'variable-input'),
@@ -183,6 +187,11 @@ skip_content_elements = [
     (text_uri, 'tracked-changes')
     ]
 
+contexts = [
+    (text_uri, 'p', 'paragraph'),
+    (text_uri, 'h', 'heading'),
+]
+
 
 # XXX These elements appear in openDocuments but they are neither in the doc,
 # nor the relaxNG file!
@@ -216,6 +225,9 @@ for uri, element_name in unknown_elements:
         raise ValueError, 'element "%s" is defined twice' % element_name
     elements[element_name] = ElementSchema(element_name,
                                            default_datatype=String)
+for uri, element_name, context in contexts:
+    element = namespaces[uri].get_element_schema(element_name)
+    element.context = context
 
 # The namespaces fo and svg have two names
 fo_uri_2 = 'http://www.w3.org/1999/XSL/Format'
