@@ -129,7 +129,7 @@ def pmltopdf(document, path=None):
     return make_pdf(events)
 
 
-def stl_pmltopdf(document, namespace=freeze({}), path=None):
+def stl_pmltopdf(document, namespace=freeze({}), path=None, mode='pdf'):
     """
     document: XMLFile, events, XMLParser, generator
     path: the path of the document
@@ -151,7 +151,11 @@ def stl_pmltopdf(document, namespace=freeze({}), path=None):
         prefix = here.resolve2(Path(path))
         events = set_prefix(events, prefix, ns_uri=pml_uri)
 
-    return make_pdf(events)
+    if mode == 'events':
+        return events
+    elif mode == 'pdf':
+        return make_pdf(events)
+    raise ValueError, 'unexpected mode "%s"' % mode
 
 
 
@@ -391,7 +395,7 @@ class Context(object):
         return copy.deepcopy(self.footer)
 
 
-    def __del__(self):
+    def del_tmp_dir(self):
         if vfs.exists(self.tmp_dir):
             vfs.remove(self.tmp_dir)
 
@@ -406,8 +410,10 @@ def document_stream(stream, pdf_stream, is_test=False):
     """
 
     # Reportlab, HACK to prevent too many open files error with inline images
-    previous_imageReaderFlags = reportlab.rl_config.imageReaderFlags
-    reportlab.rl_config.imageReaderFlags = -1
+    previous_imageReaderFlags = None
+    if hasattr(reportlab.rl_config, 'imageReaderFlags'):
+        previous_imageReaderFlags = reportlab.rl_config.imageReaderFlags
+        reportlab.rl_config.imageReaderFlags = -1
 
     story = []
     context = Context()
@@ -488,7 +494,11 @@ def document_stream(stream, pdf_stream, is_test=False):
         doc.build(story)
 
     # Reportlab, HACK to prevent too many open files error with inline images
-    reportlab.rl_config.imageReaderFlags = previous_imageReaderFlags
+    if previous_imageReaderFlags:
+        reportlab.rl_config.imageReaderFlags = previous_imageReaderFlags
+
+    # Remove temporary directory
+    context.del_tmp_dir()
 
     if is_test == True:
         return test_data
