@@ -15,10 +15,11 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # Import from itools
-from stl import STLSyntaxError, STLNameError, STLTypeError
-from stl import stl, set_prefix
+from stl import STLError, STLTemplate, stl, set_prefix
 
 
 __all__ = [
-    'stl', 'set_prefix',
-    'STLSyntaxError', 'STLNameError', 'STLTypeError']
+    'STLError',
+    'stl',
+    'STLTemplate',
+    'set_prefix']
