@@ -1,5 +1,4 @@
 # -*- coding: UTF-8 -*-
-# Copyright (C) 2005 Nicolas Oyez <nicoyez@gmail.com>
 # Copyright (C) 2005-2007 Juan David Ibáñez Palomar <jdavid@itaapy.com>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -19,11 +18,16 @@
 import mimetypes
 
 # Import from itools
-from tmx import TMX, Sentence, Message, Note
+from tmx import TMXFile, Sentence, TMXUnit, TMXNote
+from itools.utils import get_abspath
+from itools.xml import register_dtd
 
 
-__all__ = ['TMX', 'Sentence', 'Message', 'Note']
+__all__ = ['TMXFile', 'Sentence', 'TMXUnit', 'TMXNote']
 
 
 mimetypes.add_type('application/x-tmx', '.tmx')
 
+# Register DTD
+register_dtd(get_abspath('tmx14.dtd'),
+             uri='http://www.lisa.org/tmx/tmx14.dtd')
