@@ -1,6 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright (C) 2005 Nicolas Oyez <nicoyez@gmail.com>
-# Copyright (C) 2006-2007 Juan David Ibáñez Palomar <jdavid@itaapy.com>
+# Copyright (C) 2006-2008 Juan David Ibáñez Palomar <jdavid@itaapy.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,12 +18,19 @@
 from mimetypes import add_type
 
 # Import from itools
-from xliff import XLIFF, Translation, Note, File
+from itools.utils import get_abspath
+from itools.xml import register_dtd
+from xliff import XLFFile, XLFUnit, XLFNote, File
 
 
-__all__ = ['XLIFF', 'Translation', 'Note', 'File']
-
+__all__ = ['XLFFile', 'XLFUnit', 'XLFNote', 'File']
 
 
+# Register mime type
 add_type('application/x-xliff', '.xlf')
 
+# Register DTD
+# -//XLIFF//DTD XLIFF//EN
+register_dtd(get_abspath('xliff.dtd'),
+             urn='urn:publicid:-:XLIFF:DTD+XLIFF:EN')
+
